function [Coeff, indx] = OMP_Gabor(xObs,Dict,T,E2M)
%------------------------------------------------------------------------
% Function for Orthogonal Matching Pursuit (OMP)using the Gabor dictionary. 
% The method jointly selects cosine and sine atoms at the same frequency
% Inputs:
%   x: vector of the selected frame 
%   Dict: the dictionary 
%   T: maximum number of coefficients 
%   E2M: Tolerance 
% Outputs:
%   Coeff: vector of the output coefficients
%   indx: indices of the selected atoms from Dict
% -------------------------------------------------------------------------
% Function implemented in the Audio Inpainting Toolbox which can be downloaded 
% from: http://www.small-project.eu/software-data/AudioInpaintingToolbox.zip/view.html
% The Function was modified by: Toumi.I
% October 2017
% ------------------------------------------------------------------------


% Build and normalized dictionary

Dict1 = Dict(:,1:end/2);
Dict2 = Dict(:,end/2+1:end);
Dict1Dict2 = sum(Dict1.*Dict2);
n12 = 1./(1-Dict1Dict2.^2);

% OMP iterations
residual=xObs;
maxNumCoef = T;
indx = [];
currResNorm2 = E2M*2; % set a value above the threshold in order to have/force at least one loop executed
j = 0;

while j < maxNumCoef %&& currResNorm2>E2M 
    j = j+1;
    
    % Atom selection
    proj=residual'*Dict;
    proj1 = proj(1:end/2);
    proj2 = proj(end/2+1:end);
    
    alpha_j = (proj1-Dict1Dict2.*proj2).*n12;
    beta_j = (proj2-Dict1Dict2.*proj1).*n12;
    
    err_j = sum(abs(repmat(residual,1,size(Dict1,2))-Dict1*sparse(diag(alpha_j))-Dict2*sparse(diag(beta_j))).^2);
    [~, pos] = min(err_j);
    
    % Update support
    indx(end+1)=pos;
    indx(end+1)=pos+size(Dict1,2);
    
    % Update solution
    a=pinv(Dict(:,indx(1:2*j)))*xObs;
    
    % Update residue
    residual=xObs-Dict(:,indx(1:2*j))*a;
    
    % Compute error
    currResNorm2=sum(residual.^2);
end;

Coeff = sparse(size(Dict,2),1);
Coeff(indx) = a;

return


