function D = Gabor_Dict(N,rd)
% Windowed Gabor dictionary. In this implementation, the dictionary matrix
% is the concatenation of a DCT (left part of the matrix) and of a DST
% (right part).
% Note that one can use this dictionary 
%  - either by constraining the simulaneous selection of cosine and sine
%  atoms with same frequency in order to implement Gabor atoms;
%  - or, without any selection constraint, by considering that the
%  dictionary is not a Gabor dictionary but the concatenation of a DCT and 
%  of a DST.
% -------------------
% Function implemented in the Audio Inpainting Toolbox which can be downloaded 
% from: http://www.small-project.eu/software-data/AudioInpaintingToolbox.zip/view.html
% The code is distributed under the terms of the GNU Public License version 3
% Modified by Toumi.I
% --------------------

K = N*rd;       % number of atoms
wd = wRect(N);  % weigthing window
u = 0:(N-1); % time
k=0:K/2-1;      % frequency
D = diag(wd)*[cos(2*pi/K*(u.'+1/2)*(k+1/2)),sin(2*pi/K*(u.'+1/2)*(k+1/2))];

% normalisation
D = D*diag(1./sqrt(diag(D'*D)));

return
