% -------------------------------------------------------------------------
% Function to plot the inpainting results (SNR variation vs. Percentage of
% missing data)
% By: Toumi.I
% LIF, 2017
% -------------------------------------------------------------------------

clear all
close all

setpath;

soundname = [{'Speech'} {'Piano'}];
percentage = [10, 20, 30, 40, 50, 60, 70, 80, 90]; 

lf = length(soundname);
lp = length(percentage);

%% Load results 

SNR_ALL_OMP = zeros(lf,lp);
SNR_ALL_OMPG = zeros(lf,lp);
SNR_ALL_SOMP = zeros(lf,lp);

SNR_MISS_OMP = zeros(lf,lp);
SNR_MISS_OMPG = zeros(lf,lp);
SNR_MISS_SOMP = zeros(lf,lp);

for i = 1:lf
    for j = 1:lp
        filename=['Inpainting_' soundname{i} '_RandomHoles_' num2str(percentage(j)) 'percent'];
        load(filename,'SNR_OMP_allsamples',... 
            'SNR_OMP_missingsamples','SNR_OMPG_allsamples','SNR_OMPG_missingsamples','SNR_SOMP_allsamples',...
            'SNR_SOMP_missingsamples');
        
        SNR_ALL_OMP(i,j) = SNR_OMP_allsamples;
        SNR_MISS_OMP(i,j) = SNR_OMP_missingsamples;

        SNR_ALL_OMPG(i,j) = SNR_OMPG_allsamples;
        SNR_MISS_OMPG(i,j) = SNR_OMPG_missingsamples;

        SNR_ALL_SOMP(i,j) = SNR_SOMP_allsamples;
        SNR_MISS_SOMP(i,j) = SNR_SOMP_missingsamples;
    end
end

%% SNR average 

Mean_SNR_ALL_OMP =mean(SNR_ALL_OMP);
Mean_SNR_MISS_OMP =mean(SNR_MISS_OMP);

Mean_SNR_ALL_OMPG =mean(SNR_ALL_OMPG);
Mean_SNR_MISS_OMPG =mean(SNR_MISS_OMPG);

Mean_SNR_ALL_SOMP =mean(SNR_ALL_SOMP);
Mean_SNR_MISS_SOMP =mean(SNR_MISS_SOMP);

%% Plot figures

figure; 
set(gcf,'Color',[1,1,1]);
subplot(121); hold on; 
plot(percentage,Mean_SNR_ALL_SOMP,'-rs','LineWidth',1.2);plot(percentage,Mean_SNR_ALL_OMP,'-*','LineWidth',1.2); 
plot(percentage,Mean_SNR_ALL_OMPG,'-kv','LineWidth',1.2); grid on; legend('S-OMP F','OMP F','OMP G');
xlabel('Percentage of missing samples (%)','fontsize',12,'fontWeight','bold');
ylabel('Average SNR_{full} (dB)','fontsize',12,'fontWeight','bold'); axis square
subplot(122);hold on; 
plot(percentage,Mean_SNR_MISS_SOMP,'-rs','LineWidth',1.2);plot(percentage,Mean_SNR_MISS_OMP,'-*','LineWidth',1.2); 
plot(percentage,Mean_SNR_MISS_OMPG,'-kv','LineWidth',1.2); grid on ; legend('S-OMP F','OMP F','OMP G');
xlabel('Percentage of missing samples (%)','fontsize',12,'fontWeight','bold');
ylabel('Average SNR_m (dB)','fontsize',12,'fontWeight','bold'); axis square


% E.O.F