% ----------------------------------------------------------------
% Fonction to plot the average SNR vs. missing interval durations 
% LIF 2017
% By: Toumi.I
% ----------------------------------------------------------------
clear all
close all

setpath;

soundname = [{'Speech'} {'Piano'}];
HoleSize = [2, 4, 8, 16, 32]; 

lf = length(soundname);
ln = length(HoleSize);

%% Load results

SNR_ALL_OMP = zeros(lf,ln);
SNR_ALL_OMPG = zeros(lf,ln);
SNR_ALL_SOMP = zeros(lf,ln);

SNR_MISS_OMP = zeros(lf,ln);
SNR_MISS_OMPG = zeros(lf,ln);
SNR_MISS_SOMP = zeros(lf,ln);

for i = 1:lf
    for j = 1:ln
        filename=['Inpainting_' soundname{i} '_RandomHoles_50percent_size' num2str(HoleSize(j))];
        
        load(filename,'SNR_SOMP_allsamples','SNR_SOMP_missingsamples','SNR_OMP_allsamples',...
            'SNR_OMPG_allsamples','SNR_OMP_missingsamples','SNR_OMPG_missingsamples');
        
        SNR_ALL_OMP(i,j) = SNR_OMP_allsamples;
        SNR_MISS_OMP(i,j) = SNR_OMP_missingsamples;
        
        SNR_ALL_OMPG(i,j) = SNR_OMPG_allsamples;
        SNR_MISS_OMPG(i,j) = SNR_OMPG_missingsamples;
        
        SNR_ALL_SOMP(i,j) = SNR_SOMP_allsamples;
        SNR_MISS_SOMP(i,j) = SNR_SOMP_missingsamples;
    end
end

%% Average SNR computed on missing parts

Mean_SNR_ALL_OMP =mean(SNR_ALL_OMP);
Mean_SNR_MISS_OMP =mean(SNR_MISS_OMP);

Mean_SNR_ALL_OMPG =mean(SNR_ALL_OMPG);
Mean_SNR_MISS_OMPG =mean(SNR_MISS_OMPG);

Mean_SNR_ALL_SOMP =mean(SNR_ALL_SOMP);
Mean_SNR_MISS_SOMP =mean(SNR_MISS_SOMP);

%% Plot figures

Fs = 8000; % in Hz
HoleSize_ms = ([2,4,8,16,32]/Fs)* 1000;  % in ms

figure (1);
set(gcf,'Color',[1,1,1]); hold on;
plot(HoleSize_ms,Mean_SNR_MISS_SOMP,'-rs','LineWidth',1.2); 
plot(HoleSize_ms,Mean_SNR_MISS_OMP,'-*','LineWidth',1.2); 
plot(HoleSize_ms,Mean_SNR_MISS_OMPG,'-kv','LineWidth',1.2); legend('S-OMP F','OMP F','OMP G');
xlabel('Missing Interval Duration (ms)','fontsize',12,'fontWeight','bold');
ylabel('Average SNRm (dB)','fontsize',12,'fontWeight','bold'); axis square; grid on